LocalNotificationMasamuneAdapter class abstract
MasamuneAdapter for receiving local PUSH notifications.
ローカルPUSH通知を受信するためのMasamuneAdapterです。
- Inheritance
-
- Object
- MasamuneAdapter
- LocalNotificationMasamuneAdapter
Constructors
-
LocalNotificationMasamuneAdapter({required String androidNotificationChannelId, required String androidNotificationChannelTitle, required String androidNotificationChannelDescription, LocalNotification? localNotification, ModelAdapter? modelAdapter, List<
LoggerAdapter> loggerAdapters = const [], String androidDefaultIcon = "@mipmap/ic_launcher", FutureOr<void> onLink(Uri? link)?, String defaultTimezone = "UTC", bool listenOnBoot = false}) -
MasamuneAdapterfor receiving local PUSH notifications.const
Properties
- androidDefaultIcon → String
-
Android default icon.
final
- androidNotificationChannelDescription → String
-
This is a description of the notification channels supported only on Android.
final
- androidNotificationChannelId → String
-
Notification channel IDs supported only by Android.
final
- androidNotificationChannelTitle → String
-
This is the title of a notification channel that is only supported by Android.
final
- defaultTimezone → String
-
Default time zone.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTest → bool
-
If this is
true, it indicates that test adapters are set inTestMasamuneAdapterScope.setTestAdaptersand it is in test mode.no setterinherited - listenOnBoot → bool
-
trueif localNotification is set totrueto start monitoring when onMaybeBoot is executed.final - localNotification → LocalNotification?
-
Specify the object of LocalNotification.
final
-
loggerAdapters
→ List<
LoggerAdapter> -
Adapters can be defined to add logger functionality.
final
-
masamuneAdapters
→ List<
MasamuneAdapter> -
You can define adapters to add features to the Masamune Framework.
no setterinherited
- modelAdapter → ModelAdapter?
-
Specify a
ModelAdapterto register the PUSH notification schedule.final -
Observers can be set up to monitor transitions between pages.
no setterinherited
-
onLink
→ FutureOr<
void> Function(Uri? link)? -
Callback when the URL is launched.
final
- priority → double
-
The priority of the adapter.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- runZonedGuarded → bool
-
If you set this to
true, you can wrap runApp withrunZonedGuarded.no setterinherited
Methods
-
addSchedule(
String uid, {required String title, required String text, required DateTime time, int? badgeCount, LocalNotificationRepeatSettings repeat = LocalNotificationRepeatSettings.none, NotificationSound sound = NotificationSound.defaultSound, DynamicMap? data, Uri? link, String? timezone}) → Future< int?> - Add a schedule.
-
listen(
) → Future< int?> - Initialization. If the application is launched from a notification, the content of the notification is retrieved.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onBuildApp(
BuildContext context, Widget app) → Widget -
Widgets can be added during the build of
MasamuneApp.override -
onBuildPage(
BuildContext context, Widget page) → Widget -
Returning Widget will build the widget.
inherited
-
onError(
Object error, StackTrace stackTrace) → void -
You can describe the process when
runZonedGuardedis set totrue.inherited -
onInitScope(
MasamuneAdapter adapter) → void -
Called when initializing
MasamuneAdapterScope.override -
onMaybeBoot(
BuildContext context) → FutureOr< void> -
It may be called during application initialization.
override
-
onPreRunApp(
WidgetsBinding binding) → FutureOr< void> -
You can describe the process before runApp.
inherited
-
onRestarted(
) → FutureOr< void> -
It may be called when the application is restarted.
inherited
-
removeAllSchedule(
) → Future< void> - Remove all schedules.
-
removeSchedule(
String uid) → Future< int?> - Remove the schedule.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- primary → LocalNotificationMasamuneAdapter
-
You can retrieve the LocalNotificationMasamuneAdapter first given by
MasamuneAdapterScope.no setter