ModelServerCommandCopyDocumentSchedule class
ModelServerCommandBase to copy all documents to time.
Specify the path of the destination document in path.
If you use this in firestore, please specify the fields _time and _done in CollectionID:schedule to create the index.
timeにドキュメントをすべてコピーするためのModelServerCommandBaseです。
pathにコピー先のドキュメントのパスを指定します。
firestoreでこちらを利用する場合CollectionID:scheduleで_timeと_doneのフィールドを指定してインデックスを作成してください。
- Inheritance
- Implemented types
-
- Comparable<
ModelServerCommandBase>
- Comparable<
Constructors
- ModelServerCommandCopyDocumentSchedule({required String path, required ModelTimestamp time})
-
ModelServerCommandBaseto copy all documents totime.constfactory - ModelServerCommandCopyDocumentSchedule.fromJson(DynamicMap json)
-
Convert from
jsonmap to ModelServerCommandCopyDocumentSchedule.factory - ModelServerCommandCopyDocumentSchedule.fromServer({DynamicMap publicParameters = const {}, DynamicMap privateParameters = const {}})
-
Used to disguise the retrieval of data from the server.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
The path of the destination document.
no setter
- privateParameters → DynamicMap
-
Private parameters for the command.
no setteroverride
- publicParameters → DynamicMap
-
Public parameters for the command.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- time → ModelTimestamp
-
Specify the date and time to copy.
no setter
- value → String
-
Actual value.
no setterinherited
Methods
-
compareTo(
ModelServerCommandBase other) → int -
Compares this object to another object.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → DynamicMap -
Methods for Json serialization.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited